function y = gps2utc(x)

%GPS2UTC converts GPS time to UTC time
%
%SYNOPSIS
%  Y = gps2utc(X)
%
%INPUT
%   X - GPS time in seconds (vectorized)
%
%OUTPUT
%   Y - UTC time as year, month, day, hour, min, sec (vectorized)
%
%AUTHOR
%   Shantanu Desai (No longer part of the LV Collaboration)

% $Id: gps2utc.m 6645 2010-12-09 16:09:14Z diego.menendez@LIGO.ORG $

% the number of days within this GPS time
daySec = 24*3600;
Nday = x / daySec;

% The GPS clock started on Jan.6, 1980. This corresponds to
N0 = datenum('6-Jan-1980');

% shift the starting date from Jan.6, 1980 to Jan.1, year 0
Nday = Nday + N0;

%  Output as date vector
y = datevec(Nday);

return
