function y = lst(gast,ifo);

%LST - Converts Greenwich apparent sidereal time to local sidereal time
%
%SYNOPSIS
%  Y = lst(GAST,IFO)
%
%INPUTS 
%   GAST - Greenwich apparent sidereal time
%   IFO - either H1,H2,L1,GEO,VIRGO,TAMA 
% 
%OUTPUT
%   Y - local sidereal time 
%
% Longitudes of ifos from gr-qc/9607075
%
%AUTHOR
%   Shantanu Desai (No longer part of the LV Collaboration)

%  $Id: lst.m 6645 2010-12-09 16:09:14Z diego.menendez@LIGO.ORG $

switch ifo
	case 'H1' ;
	 long = -119.41 ;
	case 'H2'
	 long =  -119.41 ;
	case 'L1'
	 long = -90.77 ;
	case 'GEO'
	 long = 9.81 ;
        case 'VIRGO'
	 long = 10.5 ;
	case 'TAMA' 
	  long = 139.54 ;
	otherwise
	  warning ('undefined IFO');
	  long = 0 ;
end

y = gast + long/15.0;

% make sure Local sidereal time is between 0 and 24 hours
% one iteration should be enough
if (y >= 24.0)	
	y = y - 24.0 ;
end
if  (y <0)
	y = y + 24.0 ;
end

return
