function greaterEqualThan = gpsgreaterequal(gpsTime1,gpsTime2)
%GPSGREATEREQUAL Test that GPS time >= another GPS time in (S,NS)
%
%   INPUT
%       gpsTime1: GPS time to be tested. Either integer seconds or struct
% with elements sec, ns
%           sec: whole seconds
%           ns: residue in nano-seconds
%       gpsTime2: GPS time to be compared to. Either integer seconds or
% struct with elements sec, ns
%
%   OUTPUT
%       greaterEqualThan: true if gpsTime1 >= gpsTime2, false otherwise
% 
% gpsTime1 or gpsTime2 may be 1-dimensional arrays. If both
% are arrays they must have same length. If input is an
% array, output is a struct array. 
%
% $Id: gpsgreaterequal.m 6645 2010-12-09 16:09:14Z diego.menendez@LIGO.ORG $

% IF # input arguments is wrong
%   CREATE error
% EXIT
error(nargchk(2,2,nargin),'struct')

% IF T1 is a GPS structure
%	GET sec, ns from structure
% ELSE
%   CONVERT time to GPS structure
%	GET sec, ns from structure
% END
% IF T2 is a GPS structure
%	GET sec, ns from structure
% ELSE
%   CONVERT time to GPS structure
%	GET sec, ns from structure
% END
if(isstruct(gpsTime1))
	t1Sec = [gpsTime1(:).sec];
	t1NSec = [gpsTime1(:).ns];
else
	t1 = time2gps(gpsTime1);
    t1Sec = [t1(:).sec];
	t1NSec = [t1(:).ns];
end
if(isstruct(gpsTime2))
	t2Sec = [gpsTime2(:).sec];
	t2NSec = [gpsTime2(:).ns];
else
	t2 = time2gps(gpsTime2);
    t2Sec = [t2(:).sec];
	t2NSec = [t2(:).ns];
end

% FIND differences in whole seconds (dS)
% FIND cases where whole second difference = 0 (dS = 0)
% LOOP over dS = 0 cases
%   SET difference = difference in nanoseconds (dNs)
% ENDLOOP
% LOOP over differences
%   IF differnce >= 0
%       SET output = true
%   ELSE
%       SET output = false
%   ENDIF
% ENDIF
dS = t1Sec - t2Sec;
dNS = t1NSec - t2NSec;
diffVal = dS;
zeroIdx = find(diffVal == 0);
diffVal(zeroIdx) = dNS(zeroIdx);
greaterEqualThan = diffVal >= 0;
return
