function fixedStr = fixunderscore(rawStr)

%FIXUNDERSCORE - replace _ with \_ in string
%
%SYNOPSIS
%   FIXEDSTR = fixunderscore(RAWSTR)
%
%INPUT
%   RAWSTR - raw string that might have underscores
%
%OUTPUT
%   FIXSTR - same string with _ replaced with \_
%
%  In MATLAB figure titles, an underscore(_) is interpreted as a 
%  sub-script command.  To remedy this, replace the underscores with \_
%
%AUTHOR
%   Keith Thorne <keith.thorne@ligo.org>

%  $Id: fixunderscore.m 6645 2010-12-09 16:09:14Z diego.menendez@LIGO.ORG $

fixedStr = [];
scorePos = strfind(rawStr,'_');
if (isempty(scorePos))
    fixedStr = rawStr;
    return
end
numScore = numel(scorePos);
lastBeg = 1;
for k=1:numScore
    lastEnd = scorePos(k)-1;
    if(isempty(fixedStr))
        fixedStr = strcat(rawStr(lastBeg:lastEnd),'\_');
    else
        fixedStr = strcat(fixedStr,rawStr(lastBeg:lastEnd),'\_');
    end
    lastBeg = scorePos(k)+1;
end
fixedStr = strcat(fixedStr,rawStr(lastBeg:end));
return
