function mkplotbold(varargin)

%MKPLOTBOLD makes figure label, axes bold, bigger
%
%SYNOPSIS
%   mkplotbold(LINEWIDTH,MARKERSIZE)
%
%INPUTS
%       LINEWIDTH - [OPTIONAL] Line width
%                   <default> 2.0
%       MARKERSIZE - [OPTIONAL] Marker size
%                    <default> unchanged
%
%AUTHOR
%   Keith Thorne <keith.thorne@ligo.org>

% $Id: mkplotbold.m 6645 2010-12-09 16:09:14Z diego.menendez@LIGO.ORG $

% GET handles to axes
% LOOP over axes
%   SET tick labels as bold, 16 point
%   SET line widths to 2.0
%       we need to separately do title, axis labels
%   RESET title as bold, 16 pt
%   RESET x-axis as bold, 16 pt
%   RESET y-axis as bold, 16 pt
%   SET all plotted line widths to 2.0, marker 10.0
% ENDLOOP over axes
if(nargin > 0)
    lineWidth = varargin{1};
else
    lineWidth = 2.0;
end
if(nargin > 1)
    markerSize = varargin{2};
else
    markerSize = 0;
end
axeHand = findobj('Type','axes');
numAx = numel(axeHand);
for ax = 1:numAx
    set(axeHand(ax),'FontSize',16,'FontWeight','bold','LineWidth',2.0);
    set(get(axeHand(ax),'Title'),'FontSize',16,'FontWeight','bold');
    set(get(axeHand(ax),'XLabel'),'FontSize',16,'FontWeight','bold');
    set(get(axeHand(ax),'YLabel'),'FontSize',16','FontWeight','bold');
    if(markerSize > 0)
        set(findobj(axeHand(ax),'Type','line'),'LineWidth',lineWidth,...
            'MarkerSize',markerSize);
    else
        set(findobj(axeHand(ax),'Type','line'),'LineWidth',lineWidth);
    end
end
return
